@@ -32,14 +32,19 @@ try:
 except:
     HAS_LOOSE_VERSION = False
 
-AWS_REGIONS = ['ap-northeast-1',
-               'ap-southeast-1',
-               'ap-southeast-2',
-               'eu-west-1',
-               'sa-east-1',
-               'us-east-1',
-               'us-west-1',
-               'us-west-2']
+AWS_REGIONS = [
+    'ap-northeast-1',
+    'ap-southeast-1',
+    'ap-southeast-2',
+    'cn-north-1',
+    'eu-central-1',
+    'eu-west-1',
+    'sa-east-1',
+    'us-east-1',
+    'us-west-1',
+    'us-west-2',
+    'us-gov-west-1',
+]
 
 
 def aws_common_argument_spec():
@@ -51,7 +56,6 @@ def aws_common_argument_spec():
         security_token=dict(no_log=True),
         profile=dict(),
     )
-    return spec
 
 
 def ec2_argument_spec():
